@@ -21,13 +21,13 @@ from time import gmtime, strftime
 import sys
 
 
-file_handler = logging.FileHandler(filename='hratio_%s.log' % (strftime("%Y-%m-%dT%H:%M:%S", gmtime())))
-stdout_handler = logging.StreamHandler(sys.stdout)
-handlers = [stdout_handler, file_handler]
-
-logging.basicConfig(level=logging.INFO, format=' %(levelname)s - %(message)s', handlers=handlers)
+# file_handler = logging.FileHandler(filename='hratio_%s.log' % (strftime("%Y-%m-%dT%H:%M:%S", gmtime())))
+# stdout_handler = logging.StreamHandler(sys.stdout)
+# handlers = [stdout_handler, file_handler]
+#
+# logging.basicConfig(level=logging.INFO, format=' %(levelname)s - %(message)s', handlers=handlers)
 #[%(asctime)s] {%(filename)s:%(lineno)d}
-logger = logging.getLogger()
+logger = logging.getLogger('')
 
 class observation(object):
     _mjdref_ = 0
@@ -118,8 +118,8 @@ class light_curve(observation):
             self._dtimes_ = np.ones(len(self._times_)) * self._timedel_
 
         if self._gti_header_ is not None:
-            self._gti_start_ = self._gti_header_.data['START']
-            self._gti_stop_ = self._gti_header_.data['STOP']
+            self._gti_start_ = ff[gti_ind].data['START']
+            self._gti_stop_ = ff[gti_ind].data['STOP']
         else:
             logger.warning('No GTI, using data start and stop')
             self._gti_start_ = np.array([self._tstart_])
@@ -629,8 +629,8 @@ class light_curve(observation):
         self._frac_exp_ = new_frac_exp
 
 
-def hratio_func(soft_lcname, hard_lcname, hratio_fname, min_sn: float, max_time=1e4, gti_threshold=100, flag_rebin=1, min_bin_size=0,
-           ext_t0=-1, max_point_sn=100, single_point_check=False):
+def hratio_func(soft_lcname, hard_lcname, hratio_fname, min_sn: float, max_time=1e4, gti_threshold=100, flag_rebin=1,
+                min_bin_size=0, ext_t0=-1, max_point_sn=100, single_point_check=False):
 
     logger.info("Soft LC " + soft_lcname)
     logger.info("Hard LC " + hard_lcname)
